#[repr(C, packed(1))]pub struct PingMessage {
pub header: GNUNET_MessageHeader,
pub iv_seed: u32,
pub target: GNUNET_PeerIdentity,
pub challenge: u32,
}Expand description
We’re sending an (encrypted) PING to the other peer to check if it can decrypt. The other peer should respond with a PONG with the same content, except this time encrypted with the receiver’s key.
Fields
header: GNUNET_MessageHeaderMessage type is #GNUNET_MESSAGE_TYPE_CORE_PING.
iv_seed: u32Seed for the IV
target: GNUNET_PeerIdentityIntended target of the PING, used primarily to check that decryption actually worked.
challenge: u32Random number chosen to make replay harder.